@@ -3,9 +3,14 @@
 replace_value_mvector <- function(x, i, value) {
   if(x@readonly) stop("Read-only object")
   I <- as.integer(i) - 1L
-  if(x@datatype == "float" | x@datatype == "double") val <- as.double(value)
-  if(x@datatype == "integer" | x@datatype == "short" ) val <- as.integer(value)
-  set_values_mmatrix(x@ptr, x@datatype, I, 0L, value)
+  if(x@datatype == "float" | x@datatype == "double") {
+    val <- as.double(value)
+  } else if(x@datatype == "integer" | x@datatype == "short") {
+    val <- as.integer(value)
+  } else {
+    stop("Unsupported data type")
+  }
+  set_values_mvector(x@ptr, x@datatype, I, value)
   x
 }
 
@@ -20,11 +25,10 @@ setMethod("[<-", c(x = "mvector", i = "missing", j = "missing", value = "numeric
 )
 
 # -------------------- replacement is a mvector / mmatrix
-
 replace_value_mvector_mm <- function(x, i, value) {
   if(x@readonly) stop("Read-only object")
   I <- as.integer(i) - 1L
-  set_values_mmatrix_mm(x@ptr, x@datatype, I, 0L, value@ptr, value@datatype)
+  set_values_mvector_mm(x@ptr, x@datatype, I, value@ptr, value@datatype)
   x
 }
 
